@@ -501,7 +501,7 @@ namespace apg {
         }
 
         hypernode<I> pattern_match(hypernode<I> u, hypernode<I> c0, hypernode<I> c1) {
-            hypernode<I> v = pyramid_up(pyramid_up(pyramid_up(u, c0.depth), c1.depth));
+            hypernode<I> v = pyramid_up(pyramid_up(pyramid_up(pyramid_up(u, c0.depth), c1.depth)));
             hypernode<I> sol = solid(v.depth);
             hypernode<I> sol2 = solid(v.depth-1);
             hypernode<I> rc0 = pyramid_up(transform_recurse(c0, 27), v.depth);
