@@ -57,10 +57,10 @@ def ensure_stack(required):
     try:
         import resource
         sl, hl = resource.getrlimit(resource.RLIMIT_STACK)
-        if (sl < required):
+        if 0 < sl < required: # Pythonic chained comparators
             resource.setrlimit(resource.RLIMIT_STACK, (required, hl))
             sl, hl = resource.getrlimit(resource.RLIMIT_STACK)
-            return (sl, hl)
+        return (sl, hl)
     except Exception as e:
         return None
 
@@ -76,7 +76,7 @@ restypes = {'DeletePattern': None, 'GetBeszelIndex': c_uint64, 'GetUlqomaIndex':
             'GetSolidForPattern': c_void_p, 'GetOriginState': c_uint64, 'GetCells': None, 'SetCells': None,
             'CreatePatternFromFile': c_void_p, 'MakeSpaceshipStream': c_void_p, 'GetCompiledVersion': None,
             'GetCoords': None, 'GetPatternBound': c_uint64, 'GetSubpops': None, 'Hashsoup': c_void_p,
-            'FindConnectedComponent': c_void_p, 'GetOneCell': c_void_p}
+            'FindConnectedComponent': c_void_p, 'GetOneCell': c_void_p, 'CopyPattern': c_void_p}
 
 
 def call_underlying(lifelib, fname_and_args):
@@ -182,6 +182,7 @@ class WrappedLibrary(object):
 
     def __init__(self, soname, local_bash=None, local_python='python'):
 
+        self.last_power = 800
         soname = os.path.abspath(soname)
 
         if local_bash is None:
@@ -222,13 +223,14 @@ class WrappedLibrary(object):
         if (powerof2 > 65536):
             raise ValueError("%s exceeds maximum of 2 ^^ 5" % pname)
 
-        if (powerof2 > 800):
+        if (powerof2 > self.last_power):
             x = self('EnsureStack', powerof2 * 768)
             if x is None:
                 import warnings
                 warnings.warn("Could not ensure stack size, probably due to running on Windows. Expect segfaults soon.")
             else:
                 print("Stack size limit increased to (%d, %d)" % x)
+            self.last_power = powerof2
 
     def __del__(self):
 
