@@ -20,6 +20,14 @@ class TestGoL(unittest.TestCase):
         self.sess.lifelib.ensure_limit(20000, 1)
         self.sess.lifelib.ensure_limit(10000, 1)
 
+    def test_freywa_bug(self):
+
+        a = self.lt.pattern("bo$2bo$3o5$5bobo$6b2o$6bo")
+        b = self.lt.pattern("bo$2bo$3o")
+        self.assertEqual(a(-10, -16).match(b).nonempty(), True)
+        self.assertEqual(a(-20, -32).match(b).nonempty(), True)
+        self.assertEqual(a(-40, -64).match(b).nonempty(), True)
+
     def test_components(self):
 
         pat = self.lt.pattern('''7b3o5b3o16b3o5b3o$6bo2bo5bo2bo15bo2bo3bo2bo$6bo3bo3bo3bo15bo9bo$7b4o3b
